@@ -27,7 +27,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '2.18';
+our $VERSION = '2.19';
 
 sub db {
   my $self = shift;
@@ -83,7 +83,7 @@ sub _dequeue {
     $dbh->do("set search_path to $search_path");
   }
   ++$self->{migrated} and $self->migrations->migrate
-    if $self->auto_migrate && !$self->{migrated};
+    if !$self->{migrated} && $self->auto_migrate;
   $self->emit(connection => $dbh);
 
   return $dbh;
@@ -141,18 +141,28 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
   }
 
   # Select all rows blocking
-  $db->query('select * from names')
-    ->hashes->map(sub { $_->{name} })->join("\n")->say;
+  say $_->{name} for $db->query('select * from names')->hashes->each;
 
   # Select all rows non-blocking
+  $db->query('select * from names' => sub {
+    my ($db, $err, $results) = @_;
+    say $err and return if $err;
+    say $_->{name} for $results->hashes->each;
+  });
+  Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
+
+  # Concurrent non-blocking queries (synchronized with a delay)
   Mojo::IOLoop->delay(
     sub {
       my $delay = shift;
-      $db->query('select * from names' => $delay->begin);
+      $pg->db->query('select now()'        => $delay->begin);
+      $pg->db->query('select * from names' => $delay->begin);
     },
     sub {
-      my ($delay, $err, $results) = @_;
-      $results->hashes->map(sub { $_->{name} })->join("\n")->say;
+      my ($delay, $time_err, $time, $names_err, $names) = @_;
+      if (my $err = $time_err || $names_err) { die $err }
+      say $time->array->[0];
+      say $_->{name} for $names->hashes->each;
     }
   )->wait;
 
