@@ -46,7 +46,7 @@ sub _db {
       eval { $self->_db };
     }
   );
-  $db->listen($_) for keys %{$self->{chans}}, 'mojo_pg_pubsub';
+  $db->listen($_) for keys %{$self->{chans}}, 'mojo_pubsub';
   $self->emit(reconnect => $db);
 
   return $db;
@@ -143,6 +143,6 @@ Unsubscribe from a channel.
 
 =head1 SEE ALSO
 
-L<Mojo::Pg>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+L<Mojo::Pg>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
 
 =cut
